---
# theme id, package name, or local path
# Learn more: https://sli.dev/guide/theme-addon.html#use-theme
theme: seriph
# title of your slide, will inferred from the first header if not specified
title: Security Benchmarking for Large Language Models
# titleTemplate for the webpage, `%s` will be replaced by the slides deck's title
titleTemplate: '%s - Security Benchmarking for AI'
# information for your slides, can be a Markdown string
author: Rossi Stefano
info: |
  ## Methodologies and Applications
# keywords field for exported PDF, comma-delimited
keywords: Security, Benchmarking, Large Language Models, LLM, Red Teaming
mdc: true
hideInToc: false
# addons, can be a list of package names or local paths
# Learn more: https://sli.dev/guide/theme-addon.html#use-addon
addons:
  - slidev-addon-rabbit
  - slidev-addon-python-runner
python:
  installs: ["deepeval"]
  prelude: |
    GREETING_FROM_PRELUDE = "Hello, Slidev!"
  loadPackagesFromImports: true
  suppressDeprecationWarnings: true
  alwaysReload: false
  loadPyodideOptions: {}
# enable presenter mode, can be boolean, 'dev' or 'build'
presenter: true
# enable browser exporter, can be boolean, 'dev' or 'build'
browserExporter: dev
# enabled pdf downloading in SPA build, can also be a custom url
download: true
# filename of the export file
exportFilename: security-benchmarking-for-llms
# enable twoslash, can be boolean, 'dev' or 'build'
twoslash: false
# show line numbers in code blocks
lineNumbers: true
# enable monaco editor, can be boolean, 'dev' or 'build'
monaco: false
# controls whether texts in slides are selectable
selectable: false
# enable slide recording, can be boolean, 'dev' or 'build'
record: dev
# enable Slidev's context menu, can be boolean, 'dev' or 'build'
contextMenu: dev
# enable wake lock, can be boolean, 'dev' or 'build'
wakeLock: true
# take snapshot for each slide in the overview
overviewSnapshots: false
# force color schema for the slides, can be 'auto', 'light', or 'dark'
colorSchema: dark
# router mode for vue-router, can be "history" or "hash"
routerMode: history
# aspect ratio for the slides
aspectRatio: 16/9
# real width of the canvas, unit in px
canvasWidth: 980

# Import your custom CSS
css: unocss
# Enable UnoCSS processing
unocss:
  configFile: './uno.config.ts'

# used for theme customization, will inject root styles as `--slidev-theme-x` for attribute `x`
# themeConfig:
  # primary: '#5d8392'
# favicon, can be a local file path or URL
# favicon: 'https://cdn.jsdelivr.net/gh/slidevjs/slidev/assets/favicon.png'
# URL of PlantUML server used to render diagrams
# Learn more: https://sli.dev/features/plantuml.html
# plantUmlServer: https://www.plantuml.com/plantuml
# fonts will be auto-imported from Google fonts
# Learn more: https://sli.dev/custom/config-fonts.html
# fonts:
  # sans: Roboto
  # serif: Roboto Slab
  # mono: Fira Code
# default frontmatter applies to all slides
defaults:
  layout: default
  # ...

# drawing options
# Learn more: https://sli.dev/guide/drawing.html
drawings:
  enabled: true
  persist: false
  presenterOnly: false
  syncAll: true

# HTML tag attributes
htmlAttrs:
  dir: ltr
  lang: en

layout: center

# add slide transitions
transition: slide-left
# default slide transition
background: none
---

<div class="flex flex-col items-center justify-center h-full py-10">
  <h1 class="text-center text-5xl font-bold gradient-text mb-10">Security Benchmarking for Large Language Models</h1>
  
  <h2 class="text-center text-4xl mb-6" style="color: var(--accent-color);">Methodologies and Applications</h2>
  
  <h3 class="text-center text-3xl mb-14 animate-pulse highlight-word">Understanding, Evaluating, and Mitigating LLM Security Vulnerabilities</h3>
  
  <div class="flex w-full justify-between mt-auto">
    <div class="text-left text-xl">Rossi Stefano</div>
    <div class="text-right text-xl">14 March, 2025</div>
  </div>
</div>

<style>
.gradient-text {
  background: linear-gradient(-45deg, var(--primary-color), var(--secondary-color), var(--accent-color), var(--primary-color));
  background-size: 300% 300%;
  color: transparent;
  -webkit-background-clip: text;
  background-clip: text;
  animation: gradient-animation 6s ease infinite;
}

@keyframes gradient-animation {
  0% { background-position: 0% 50%; }
  50% { background-position: 100% 50%; }
  100% { background-position: 0% 50%; }
}
</style>

---
src: ./pages/intro.md
transition: fade
---
---
src: ./pages/risks-and-vulnerabilities.md
transition: slide-up
---
---
src: ./pages/understanding-llm-vulns.md
transition: slide-right
---
---
src: ./pages/red-teaming-methodologies.md
transition: zoom-in
---
---
src: ./pages/advanced-att-techniques.md
transition: slide-left
---
---
src: ./pages/major-bench-secu.md
transition: fade-out
---
---
src: ./pages/deepeval-example.md
transition: zoom-out
---
---
src: ./pages/best-practices.md
transition: slide-up
---
---
src: ./pages/end.md
transition: fade
---
